@@ -1,11 +1,13 @@
 from django.conf import settings
 from rest_framework import generics
 from rest_framework.generics import *
+from rest_framework.renderers import BrowsableAPIRenderer
 
 from controller.models.utils import is_singleton
 
 from . import ApiRoot
 from .helpers import build_pagination_link, model_name_urlize
+from .renderers import ResourceListJSONRenderer
 from .serializers import DynamicReadonlyFieldsModelSerializer
 from .utils import link_header
 
@@ -33,6 +35,8 @@ class URIListCreateAPIView(ControllerBase, generics.ListCreateAPIView):
     
     """
     add_serializer_class = None # Serializer used on object creation
+    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
+    
     def get_serializer_class(self):
         # TODO until the partial response is not implemented we'll serve full resources
 #        if self.request.method == 'GET' and not hasattr(self, 'response'):
@@ -83,6 +87,10 @@ class URIListCreateAPIView(ControllerBase, generics.ListCreateAPIView):
         else:
             # per_page cannot be less than 1
             per_page = max(1, per_page)
+        
+        # Is pagination disabled?
+        if per_page is None:
+            per_page = max(1, qs.count())
         paginator = Paginator(qs, per_page)
         
         # validate num_page
