@@ -10,6 +10,8 @@ from django.test import TestCase
 from nodes.models import Node
 from slices.models import Sliver
 
+from .utils.profiles import _Profile, profile_matches
+
 
 class FilteringTests(TestCase):
     fixtures = ['groups.json', 'nodes.json', 'slices.json', 'slivers.json',
@@ -246,6 +248,13 @@ class PaginationTests(TestCase):
         nodes_db = set(Node.objects.values_list('id', flat=True))
         nodes_id = set([node['id'] for node in nodes])
         self.assertEquals(nodes_db, nodes_id)
+    
+    def test_paginate_empty_queryset(self):
+        # Regression test ZeroDivisionError
+        assert not Sliver.objects.exists(), "Slivers queryset is not empty."
+        url = reverse('sliver-list')
+        resp = self.client.get(url)
+        self.assertEqual(resp.status_code, 200)
 
 
 class IntegrationTests(TestCase):
@@ -260,7 +269,9 @@ class IntegrationTests(TestCase):
         url = reverse('node-list')
         filter_query = '/set_state="production"'
         pagination = 'per_page=1&page=2'
-        resp = self.client.get(url + '?%s&%s' % (filter_query, pagination))
+        url_query = '&'.join([filter_query, pagination])
+        
+        resp = self.client.get("%s?%s" % (url, url_query))
         self.assertEqual(resp.status_code, 200)
         node_js = json.loads(resp.content)
         
@@ -271,3 +282,89 @@ class IntegrationTests(TestCase):
         # check if objects return really match
         for node in node_js:
             self.assertEqual(node['set_state'], "production")
+    
+    def test_pagination_filtering_member_selection(self):
+        url = reverse('node-list')
+        filter_query = '/set_state="production"'
+        pagination = 'per_page=1&page=2'
+        member_query = 'show=/name,/set_state'
+        url_query = '&'.join([filter_query, pagination, member_query])
+        
+        resp = self.client.get("%s?%s" % (url, url_query))
+        self.assertEqual(resp.status_code, 200)
+        node_js = json.loads(resp.content)
+        
+        # check number objects returned
+        node_qs = Node.objects.filter(set_state="production")[1:2]
+        self.assertEqual(len(node_js), node_qs.count())
+        
+        # check if objects return really match
+        for node in node_js:
+            self.assertEqual(node['set_state'], "production")
+        
+        #TODO extend test when member selection implemented
+
+
+class MemberSelectionTests(TestCase):
+    fixtures = ['groups.json']
+    
+    def test_basic_member_selection(self):
+        url = reverse('group-list')
+        member_query = 'show=/name'
+        resp = self.client.get(url + '?%s' % member_query)
+        self.assertEqual(resp.status_code, 200)
+        #TODO extend test when member selection implemented
+
+
+class ProfileTests(TestCase):
+    
+    def assertEqual_schema_profile(self, schema):
+        profile = _Profile(schema['uri'])
+        self.assertEqual(schema['api'], profile.api)
+        self.assertEqual(schema['version'], profile.version)
+        self.assertEqual(schema['resource'], profile.resource)
+    
+    def test_parse_full_profile_uri(self):
+        schema = {
+            'uri': "http://confine-project.eu/schema/registry/v0/base",
+            'api': 'registry',
+            'version': 'v0',
+            'resource': 'base',
+        }
+        self.assertEqual_schema_profile(schema)
+    
+    def test_parse_profile_version_less_uri(self):
+        schema = {
+            'uri': "http://confine-project.eu/schema/registry/base",
+            'api': 'registry',
+            'version': None,
+            'resource': 'base',
+        }
+        self.assertEqual_schema_profile(schema)
+    
+    def test_parse_resource_list_profile_uri(self):
+        schema = {
+            'uri': "http://confine-project.eu/schema/registry/v3/resource-list",
+            'api': 'registry',
+            'version': 'v3',
+            'resource': 'resource-list',
+        }
+        self.assertEqual_schema_profile(schema)
+    
+    def test_parse_invalid_profile_uri(self):
+        self.assertRaises(ValueError, _Profile, "http://foo.go")
+    
+    def test_matching_profiles_version_less(self):
+        first = "http://confine-project.eu/schema/registry/v3/node"
+        other = "http://confine-project.eu/schema/registry/node"
+        self.assertTrue(profile_matches(first, other))
+    
+    def test_matching_profiles_none(self):
+        first = None
+        other = "http://confine-project.eu/schema/registry/node"
+        self.assertTrue(profile_matches(first, other))
+    
+    def test_not_matching_profiles(self):
+        first = "http://confine-project.eu/schema/registry/v3/node"
+        other = "http://confine-project.eu/schema/registry/v0/node"
+        self.assertFalse(profile_matches(first, other))
