@@ -66,6 +66,7 @@ class BuildFileInline(admin.TabularInline):
 class ConfigFileInline(admin.TabularInline):
     model = ConfigFile
     extra = 0
+    ordering = ['-priority', 'path']
     
     def formfield_for_dbfield(self, db_field, **kwargs):
         """ Make some char input widgets larger """
@@ -123,6 +124,11 @@ class BuildAdmin(admin.ModelAdmin):
     ]
     inlines = [BuildFileInline]
     
+    class Media:
+        css = {
+             'all': ('firmware/css/firmware-build.css',)
+        }
+    
     def colored_state(self, build):
         return colored('state', STATE_COLORS)(build)
     colored_state.short_description = "State"
