@@ -2,7 +2,6 @@ from __future__ import absolute_import
 
 from permissions.admin import PermissionGenericTabularInline
 
-from .forms import MgmtNetConfInlineForm
 from .models import MgmtNetConf
 
 
@@ -12,11 +11,9 @@ class MgmtNetConfInline(PermissionGenericTabularInline):
     fields = ['backend', 'address']
     readonly_fields = ('address',)
     model = MgmtNetConf
-    form = MgmtNetConfInlineForm
     max_num = 1
     can_delete = False
     verbose_name_plural = 'management network'
 
     def address(self, obj):
         return obj.addr.strNormal()
-
