@@ -1,6 +1,4 @@
-import json
 import os
-import re
 import socket
 import time
 from optparse import make_option
@@ -8,8 +6,6 @@ from optparse import make_option
 from django.core.mail import mail_admins, get_connection
 from django.core.management.base import BaseCommand
 
-from controller.utils.system import touch
-
 from monitor import settings
 from monitor.models import TimeSerie
 
@@ -25,7 +21,7 @@ class Command(BaseCommand):
             )
     
     option_list = BaseCommand.option_list
-    help = 'Run monitors.'
+    help = 'Run monitors to diagnose system health.'
     
     def handle(self, *args, **options):
         problems = []
