@@ -17,5 +17,8 @@ NODES_NODE_SLIVER_PUB_IPV4_RANGE_DFLT = getattr(settings, 'NODES_NODE_SLIVER_PUB
 
 NODES_NODE_DIRECT_IFACES_DFLT = getattr(settings, 'NODES_NODE_DIRECT_IFACES_DFLT', [])
 
-NODES_NODE_API_NODE_BASE_URL = getattr(settings, 'NODES_NODE_API_NODE_BASE',
-    'http://[%(mgmt_addr)s]/confine/api')
+NODES_NODE_API_BASE_URI_DEFAULT = getattr(settings, 'NODES_NODE_API_BASE_URI_DEFAULT',
+    'https://[%(mgmt_addr)s]/confine/api/')
+
+NODES_SERVER_API_BASE_URI_DEFAULT = getattr(settings, 'NODES_SERVER_API_BASE_URI_DEFAULT',
+    'https://[%(mgmt_addr)s]/api/')
