@@ -14,6 +14,7 @@ from controller.admin import ChangeViewActions, ChangeListDefaultFilter
 from controller.admin.utils import (colored, admin_link, link, get_admin_link,
     insertattr, get_modeladmin, wrap_admin_view, docstring_as_help_tip)
 from controller.admin.widgets import LinkedRelatedFieldWidgetWrapper
+from controller.core.exceptions import DisallowedSliverCreation
 from nodes.admin import NodeAdmin
 from nodes.models import Node
 from permissions.admin import (PermissionModelAdmin, PermissionStackedInline,
@@ -53,16 +54,32 @@ num_slivers.admin_order_field = 'slivers__count'
 
 
 def computed_sliver_set_state(sliver):
-    sliver_state = sliver.set_state or sliver.slice.sliver_defaults.set_state
-    state = sliver.effective_set_state
-    effective = state != sliver_state
-    color = STATE_COLORS.get(state, "black")
-    state = filter(lambda s: s[0] == state, Slice.STATES)[0][1]
     title = ''
-    if effective:
-        title = 'Set state from slice, sliver set state is &quot;%s&quot;' % sliver_state
-        state += '*'
-    return mark_safe('<span style="color:%s;" title="%s">%s</span>' % (color, title, state))
+
+    # compute if state is overridden...
+    is_state_overridden = False
+    state = sliver.effective_set_state
+    sliver_state = sliver.set_state or sliver.slice.sliver_defaults.set_state
+    # ...by slice
+    if state != sliver_state and (state == Slice.REGISTER or sliver_state == Slice.START):
+        is_state_overridden = True
+        sliver_state_name = filter(lambda s: s[0] == sliver_state, Slice.STATES)[0][1]
+        title = 'Set state from slice, sliver set state is %s' % sliver_state_name
+    # ...by sliver defaults
+    if sliver.set_state is None:
+        is_state_overridden = True
+        if not title:
+            title = 'Set state from sliver defaults, sliver has no set state'
+        else:  # already overridden by slice
+            title += ' (from sliver defaults)'
+
+    # init state representation
+    color = STATE_COLORS.get(state, "black")
+    state_name = filter(lambda s: s[0] == state, Slice.STATES)[0][1]
+    if is_state_overridden:
+        state_name += '*'
+    
+    return mark_safe('<span style="color:%s;" title="%s">%s</span>' % (color, title, state_name))
 computed_sliver_set_state.short_description = 'Set state'
 
 
@@ -112,7 +129,6 @@ class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
             'description': 'If you want to define a URI, you should remove '
                            'previously the uploaded file.',
             'fields': ('data', 'data_uri', 'data_sha256',
-                       'overlay', 'overlay_uri', 'overlay_sha256',
                        'new_instance_sn')
         }),
     )
@@ -171,7 +187,7 @@ class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
         return super(SliverAdmin, self).get_form(request, obj, **kwargs)
     
     def get_readonly_fields(self, request, obj=None):
-        """Mark as readonly if exists file for data and overlay"""
+        """Mark as readonly if exists file for data."""
         readonly_fields = super(SliverAdmin, self).get_readonly_fields(request, obj=obj)
         return readonly_fields + get_readonly_file_fields(obj)
     
@@ -212,7 +228,7 @@ class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
         if db_field.name == 'set_state':
             blank_choice = (('', SLIVER_EMPTY_LABEL),)
             kwargs['choices'] = blank_choice + Slice.STATES
-        # TODO update empty_label for data and overlay (FileField)
+        # TODO update empty_label for sliver data (FileField)
         return super(SliverAdmin, self).formfield_for_choice_field(db_field, request, **kwargs)
     
     def change_view(self, request, object_id, form_url='', extra_context=None):
@@ -402,6 +418,8 @@ class SliceSliversAdmin(SliverAdmin):
         # hook for future use on self.save_model()
         slice = get_object_or_404(Slice, pk=slice_id)
         node = get_object_or_404(Node, pk=node_id)
+        if Sliver.objects.filter(node=node, slice=slice).exists():
+            raise DisallowedSliverCreation()
         self.slice_id = slice_id
         self.node_id = node_id
         title = 'Add sliver %s@%s' % (get_admin_link(slice), get_admin_link(node))
@@ -557,7 +575,7 @@ class SliverDefaultsInline(PermissionStackedInline):
             'description': 'If you want to define a URI, you should remove '
                            'previously the uploaded file.',
             'fields': ('template', 'set_state','data', 'data_uri', 'data_sha256',
-                       'overlay', 'overlay_uri', 'overlay_sha256', 'instance_sn')
+                       'instance_sn')
         }),
     )
     readonly_fields = ['instance_sn']
@@ -580,7 +598,7 @@ class SliverDefaultsInline(PermissionStackedInline):
         return super(SliverDefaultsInline, self).formfield_for_dbfield(db_field, **kwargs)
     
     def get_readonly_fields(self, request, obj=None):
-        """Mark as readonly if exists file for data and overlay"""
+        """Mark as readonly if exists file for data."""
         readonly_fields = super(SliverDefaultsInline, self).get_readonly_fields(request, obj=obj)
         if obj is None:
             return readonly_fields
