@@ -8,7 +8,6 @@ from rest_framework.response import Response
 from rest_framework.views import APIView
 
 from api import api, generics
-from api.renderers import ResourceListJSONRenderer
 from permissions.api import ApiPermissionsMixin
 
 from .models import Slice, Sliver, Template
@@ -95,8 +94,8 @@ def make_upload_file(model, field, field_url):
             else:
                 msg = "Only multipart/form-data is supported"
                 raise exceptions.ParseError(detail=msg)
-            # Slice refactor: data & overlay moved to SliverDefaults (#234)
-            # FIXME: better approach for differences template vs data|overlay?
+            # Slice refactor: data moved to SliverDefaults (#234)
+            # FIXME: better approach for differences template vs data?
             try:
                 obj = obj.sliver_defaults
             except AttributeError: # template use case
@@ -154,7 +153,6 @@ class SliceList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     model = Slice
     add_serializer_class = SliceCreateSerializer
     serializer_class = SliceSerializer
-    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
     filter_fields = ('set_state', )
 
 
@@ -173,7 +171,6 @@ class SliceDetail(generics.RetrieveUpdateDestroyAPIView):
     renderer_classes = [SliceProfileRenderer, BrowsableAPIRenderer]
     ctl = [
         Renew, Reset, make_upload_file(Slice, 'data', 'data'),
-        make_upload_file(Slice, 'overlay', 'overlay'),
     ]
     
     def put(self, request, *args, **kwargs):
@@ -207,7 +204,6 @@ class SliverList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     """
     model = Sliver
     serializer_class = SliverSerializer
-    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
     filter_fields = ('node', 'slice')
 
 
@@ -227,7 +223,6 @@ class SliverDetail(generics.RetrieveUpdateDestroyAPIView):
     renderer_classes = [SliverProfileRenderer, BrowsableAPIRenderer]
     ctl = [
         Update, make_upload_file(Sliver, 'data', 'data'),
-        make_upload_file(Sliver, 'overlay', 'overlay'),
     ]
 
 
@@ -243,7 +238,6 @@ class TemplateList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     """
     model = Template
     serializer_class = TemplateSerializer
-    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
 
 
 class TemplateDetail(generics.RetrieveUpdateDestroyAPIView):
