@@ -2,12 +2,11 @@ class NodePullHeartBeat(object):
     def process_view(self, request, view_func, view_args, view_kwargs):
         if view_func.func_name in ('NodeDetail', 'SliverDetail'):
             from controller.core.exceptions import InvalidMgmtAddress
-            from nodes.utils import get_mgmt_backend_class
-            mgmt_backend = get_mgmt_backend_class()
+            from mgmtnetworks.utils import reverse as mgmt_reverse
             META = request.META
             remote_addr = META.get('HTTP_X_REAL_IP', META['REMOTE_ADDR'])
             try:
-                client = mgmt_backend.reverse(remote_addr)
+                client = mgmt_reverse(remote_addr)
             except InvalidMgmtAddress:
                 return
             from nodes.models import Node
