@@ -7,12 +7,11 @@ from rest_framework.response import Response
 from rest_framework.views import APIView
 
 from api import api, generics
-from api.renderers import ResourceListJSONRenderer
 from permissions.api import ApiPermissionsMixin
 
-from .models import Host, Gateway
-from .renderers import GatewayProfileRenderer, HostProfileRenderer
-from .serializers import HostCreateSerializer, HostSerializer, GatewaySerializer
+from .models import Host
+from .serializers import HostCreateSerializer, HostSerializer
+from .renderers import HostProfileRenderer
 
 
 class UploadPubkey(APIView):
@@ -48,7 +47,6 @@ class HostList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     model = Host
     add_serializer_class = HostCreateSerializer
     serializer_class = HostSerializer
-    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
     
     def pre_save(self, obj):
         """ Set the object's owner, based on the incoming request. """
@@ -70,37 +68,74 @@ class HostDetail(generics.RetrieveUpdateDestroyAPIView):
     ctl = [UploadPubkey]
 
 
-class GatewayList(ApiPermissionsMixin, generics.URIListCreateAPIView):
-    """
-    **Media type:** [`application/json;
-        profile="http://confine-project.eu/schema/registry/v0/resource-list"`](
-        http://wiki.confine-project.eu/arch:rest-api#gateway_at_registry)
-    
-    This resource lists testbed [gateways](http://wiki.confine-project.eu/arch:
-    rest-api#gateway_at_registry) and provides API URIs to navigate to them.
-    """
-    model = Gateway
-    serializer_class = GatewaySerializer
-    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
-
-
-class GatewayDetail(generics.RetrieveUpdateDestroyAPIView):
-    """
-    **Media type:** [`application/json;
-        profile="http://confine-project.eu/schema/registry/v0/gateway"`](
-        http://wiki.confine-project.eu/arch:rest-api#gateway_at_registry)
-    
-    This resource describes a network gateway providing access to the testbed
-    [server](http://wiki.confine-project.eu/arch:rest-api#server_at_registry)
-    and listening on tinc addresses on one or more community network
-    [islands](http://wiki.confine-project.eu/arch:rest-api#island_at_registry).
-    The gateway connects to other gateways or the testbed server in
-    order to reach the later.
-    """
-    model = Gateway
-    serializer_class = GatewaySerializer
-    renderer_classes = [GatewayProfileRenderer, BrowsableAPIRenderer]
-
-
 api.register(HostList, HostDetail)
-api.register(GatewayList, GatewayDetail)
+
+
+# backwards compatibility #245 note-42
+import json
+from api import ApiRoot
+from api.utils import link_header
+from controller.utils import get_project_root
+from django.core.urlresolvers import reverse
+from django.http import Http404
+from os import path
+from rest_framework.decorators import api_view
+
+
+def get_headers(request):
+    base_link = [
+        ('base', ApiRoot.REGISTRY_REL_PREFIX + 'base'),
+        ('base_controller', ApiRoot.CONTROLLER_REL_PREFIX + 'base'),
+    ]
+    return {'Link': link_header(base_link, request)}
+
+
+def load_gateways_snapshot(request):
+    """
+    Read snapshot file and load gateways.
+    
+    Backwards compatibility data stored during upgrade by
+    controller/management/commands/postupgradecontroller.py
+    """
+    gateways_file = path.join(get_project_root(), 'gateways.api.json')
+    gateways = []
+    try:
+        data = open(gateways_file, "r").read()
+    except IOError:
+        pass # Doesn't exist gateway backup
+    else:
+        try:
+            gateways = json.loads(data)
+        except ValueError:
+            pass # Invalid format
+        else:
+            for gw in gateways:
+                gw_url = reverse('gateway-detail', kwargs={'pk':gw['id']})
+                gw['uri'] = request.build_absolute_uri(gw_url)
+    
+    return gateways
+    
+
+@api_view(['GET'])
+def gateway_list(request):
+    headers = get_headers(request)
+    gateways = load_gateways_snapshot(request)
+    return Response(gateways, headers=headers)
+
+
+@api_view(['GET'])
+def gateway_detail(request, pk):
+    # verify object pk
+    try:
+        pk = int(pk)
+    except (TypeError, ValueError):
+        raise Http404
+    
+    # try load gateway data from snapshot
+    headers = get_headers(request)
+    gateways = load_gateways_snapshot(request)
+    for gw in gateways:
+        if gw['id'] == pk:
+            return Response(gw, headers=headers)
+    
+    raise Http404
