@@ -92,13 +92,9 @@ class Command(BaseCommand):
                     prompt_username = None
                     continue
         
-        server, __ = Server.objects.get_or_create(pk=1)
-        if not server.description:
-            server.description = run('hostname').stdout
-            server.save()
-        
+        server = Server.objects.first()
         server_ct = ContentType.objects.get_for_model(Server)
-        tinc_server, __ = TincHost.objects.get_or_create(object_id=1,
+        tinc_server, __ = TincHost.objects.get_or_create(object_id=server.pk,
             content_type=server_ct)
         
         tinc_port = options.get('default_port')
