@@ -244,7 +244,6 @@ FLUENT_DASHBOARD_APP_ICONS = {
     'slices/slice': "ChemSlice.png",
     'slices/sliver': "LXCBox2.png",
     'slices/template': "Application-x-gerber.png",
-    'tinc/gateway': "Network.png",
     'tinc/tincaddress': "X-office-address-book.png",
     'tinc/host': "computer-dell-dimension-E521.png",
     'issues/ticket': "Ticket_star.png",
@@ -317,4 +316,4 @@ USE_ETAGS = True
 CUSTOM_API_ROOT = 'controller.api.Base'
 
 # REST API pagination
-DEFAULT_PER_PAGE = 25
+DEFAULT_PER_PAGE = None # Disable pagination by default
