@@ -22,9 +22,7 @@ class Command(BaseCommand):
             make_option('--processes', dest='processes', default=4,
                 help='uWSGI number of processes.'),
             make_option('--noinput', action='store_false', dest='interactive', default=True,
-                help='Tells Django to NOT prompt the user for input of any kind. '
-                     'You must use --username with --noinput, and must contain the '
-                     'cleeryd process owner, which is the user how will perform tincd updates'),
+                help='Tells Django to NOT prompt the user for input of any kind.'),
             )
     
     option_list = BaseCommand.option_list
@@ -36,7 +34,7 @@ class Command(BaseCommand):
         
         # Avoid import errors
         from nodes.models import Server
-        server = Server.objects.get()
+        server = Server.objects.first()
         context = {
             'project_name': get_project_name(),
             'project_root': get_project_root(),
@@ -121,7 +119,7 @@ class Command(BaseCommand):
             elif diff.return_code == 1:
                 # File is different, save the old one
                 if interactive:
-                    msg = ("\n\nFile %(file)s be updated, do you like to overide "
+                    msg = ("\n\nFile %(file)s be updated, do you like to override "
                            "it? (yes/no): " % context)
                     confirm = input(msg)
                     while 1:
