@@ -22,9 +22,7 @@ class Command(BaseCommand):
             make_option('--db_port', dest='db_port', default='5432',
                 help='Specifies the port to connect to the database.'),
             make_option('--noinput', action='store_false', dest='interactive', default=True,
-                help='Tells Django to NOT prompt the user for input of any kind. '
-                     'You must use --username with --noinput, and must contain the '
-                     'cleeryd process owner, which is the user how will perform tincd updates'),
+                help='Tells Django to NOT prompt the user for input of any kind.'),
             )
     
     option_list = BaseCommand.option_list
